//
// fraktal - visualization of Mandelbrot and Julia sets
// Copyright (C) 1999-2020  Joachim Reichel <joachim.reichel@posteo.de>
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
//

#ifndef FRAKTAL_COMPUTE_H
#define FRAKTAL_COMPUTE_H

/// The functions to be visualized.
enum Function {
    FCT_MANDELBROT,          ///< Mandelbrot function
    FCT_INVERSE_MANDELBROT,  ///< Inverse mandelbrot function
    FCT_JULIA                ///< Julia function
};

/// Computes the given function using the CPU.
void compute_cpu( float* result, int w, int h, double cx, double cy, double s, Function f, int quality, int stride);

/// Computes the given function using the GPU.
void compute_cuda( float* result, int w, int h, double cx, double cy, double s, Function f, int quality, int stride);

#endif // FRAKTAL_COMPUTE_H
