//
// fraktal - visualization of Mandelbrot and Julia sets
// Copyright (C) 1999-2020  Joachim Reichel <joachim.reichel@posteo.de>
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
//

#ifndef FRAKTAL_MAINWINDOW_H
#define FRAKTAL_MAINWINDOW_H

#include <QtWidgets/QMainWindow>

class Renderer;
class GLWidget;

class MainWindow : public QMainWindow
{
  Q_OBJECT

public:

    MainWindow();

    Renderer* get_renderer() const;
    const GLWidget* get_glwidget() const;

public slots:

    void update_menus();

    void function_mandelbrot_set();
    void function_inverse_mandelbrot_set();
    void function_julia_set();

    void mode_cpu();
    void mode_opengl();
    void mode_cuda();

    void misc_reset();
    void misc_screenshot();
    void misc_fullscreen();
    void misc_about();

    void message( const QString& message) const;
    void message_tmp( const QString& message) const;
    void message_clear() const;

protected:

    virtual void keyPressEvent( QKeyEvent* e);
    virtual void keyReleaseEvent( QKeyEvent* e);

    Renderer* m_renderer;
    GLWidget* m_glwidget;

    QMenu*    m_menu_function;
    QMenu*    m_menu_mode;
    QMenu*    m_menu_misc;

    QAction*  m_action_function_mandelbrot_set;
    QAction*  m_action_function_inverse_mandelbrot_set;
    QAction*  m_action_function_julia_set;

    QAction*  m_action_mode_cpu;
    QAction*  m_action_mode_opengl;
    QAction*  m_action_mode_cuda;

    QAction*  m_action_misc_reset;
    QAction*  m_action_misc_screenshot;
    QAction*  m_action_misc_fullscreen;
    QAction*  m_action_misc_about;
    QAction*  m_action_misc_quit;
};

#endif // FRAKTAL_MAINWINDOW_H
