//
// fraktal - visualization of Mandelbrot and Julia sets
// Copyright (C) 1999-2020  Joachim Reichel <joachim.reichel@posteo.de>
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
//

#ifndef FRAKTAL_SHADER_JULIA_H
#define FRAKTAL_SHADER_JULIA_H

#include "shader_common.h"

const char* g_julia_shader_string = " \
\
varying vec4 position; \
uniform float kmax; \
\
float julia (float x1, float y1) \
{ \
    float k = 0.0; \
    float x2; \
    float y2; \
    float d; \
\
    do \
        { \
            x2 = x1*x1 - y1*y1 + 0.11; \
            y2 = 2.0 * x1 * y1 - 0.66; \
            d  = x2*x2 + y2*y2; \
            x1 = x2; \
            y1 = y2; \
            k++; \
        } \
    while ((d <= 4.0) && (k < kmax)); \
\
    return k + log ( log(2.0*2.0)/(log(d)) ) / log (2.0); \
} \
\
" g_compute_color_string "\
\
void main() \
{ \
    float x = julia (position.x, position.y); \
    gl_FragColor = compute_color (x); \
} \
";

#endif // FRAKTAL_SHADER_JULIA_H
